import { Button, Form, Input, Select, Skeleton } from "antd";
import { useAssessmentStandardContext } from "./assessment-standard-provider";
import { api, useSport } from "@nice/client";
import toast from "react-hot-toast";
import create from "@ant-design/icons/lib/components/IconFont";

export default function SportCreateContent() {
    const { form, sportProjectList, sportProjectLoading } = useAssessmentStandardContext();
    const { createSportProject, softDeleteByIds } = useSport();
    const { data: fatherTrainContent } = api.trainContent.findFirst.useQuery({
        where: {
            type: "SPORTS",
            title: "体能考核"
        }
    })
    const handleCreateProject = async () => {
        if (form.getFieldsValue().createProjectName && form.getFieldsValue().unit) {
            await createSportProject.mutateAsync({
                data: {
                    name: form.getFieldsValue().createProjectName,
                    type: "sport",
                    unit: form.getFieldsValue().unit,
                    isAscending: true,
                    trainContent: {
                        create: {
                            title: form.getFieldsValue().createProjectName,
                            type: "SPORT",
                            parentId: fatherTrainContent?.id
                        }
                    }
                }
            } as any)
            toast.success("创建项目成功")
            form.resetFields()
        } else {
            toast.error("请输入项目名称或成绩单位")
        }
    }
    const handleDeleteProject = async (id: string) => {
        console.log(id)
        await softDeleteByIds.mutateAsync({
            ids: [id]
        } as any)
        toast.success("删除项目成功")
    }
    return (
        <>
            <Form form={form} layout="vertical">
                <div className="flex items-center space-x-4 w-1/2">
                    <Form.Item label="创建项目" name="createProjectName">
                        <Input placeholder="请输入创建的项目名称" className="mr-2" />
                    </Form.Item>
                    <Form.Item label="成绩单位" name="unit" className='w-32'>
                        <Select
                            className='mr-2 w-24'
                            placeholder="请选择成绩单位"
                            options={[
                                { value: 'time', label: '时间' },
                                { value: 'count', label: '次数' },
                            ]}
                        ></Select>
                    </Form.Item>
                    <Button type="primary" className='mt-10 ml-2' onClick={handleCreateProject}>创建项目</Button>
                </div>
                {sportProjectLoading ?
                    <Skeleton></Skeleton> :
                    <div className='w-1/3 my-3 max-h-48 overflow-y-auto'>
                        {sportProjectList?.filter(item=>item.deletedAt === null)?.map((item) => (
                            <div key={item.id} className='w-full flex justify-between p-4 mt-2 bg-white rounded-md'>
                                <div className='font-bold'>{item.name}（{item.unit}）</div>
                                <span className='text-red-500 cursor-pointer' onClick={() => handleDeleteProject(item.id)}>删除</span>
                            </div>
                        ))}
                    </div>
                }
            </Form>
        </>
    )
}