import React, {
    createContext,
    ReactNode,
    useContext,
    useEffect,
    useState,
} from "react";
import { api } from "@nice/client";
import { Form, FormInstance } from "antd";
import { useAuth } from "@web/src/providers/auth-provider";
import { RolePerms, UserProfile } from "@nice/common";
interface SportPageContextType {
    sportProjectList: {
        id: string,
        name: string,
        unit: string,
        trainContentId:string,
        deletedAt?: string | null
    }[],
    newScoreForm: FormInstance,
    isNewScoreModalVisible: boolean,
    staffsWithScoreLoading:boolean,
    handleNewScoreCancel: () => void,
    handlNewScoreOpen: () => void,
    staffs: UserProfile[] | null,
    staffsLoading: boolean
    staffsWithScore: any[] | null,
}

const SportPageContext = createContext<SportPageContextType | null>(null);
interface SportPageProviderProps {
    children: ReactNode;
}

export function SportPageProvider({ children }: SportPageProviderProps) {
    const { data: sportProjectList, isLoading: sportProjectLoading } = api.sportProject.findMany.useQuery()
    const [newScoreForm] = Form.useForm()
    const [isNewScoreModalVisible, setIsNewScoreModalVisible] = useState(false)
    const [isUpdateScoreModalVisble,setIsUpdateScoreModalVisible] = useState(false)
    const handleNewScoreCancel = () => {
        setIsNewScoreModalVisible(false)
    }
    const handlNewScoreOpen = () => {
        newScoreForm.resetFields()
        setIsNewScoreModalVisible(true)
    }
    
    

    const { user, isAuthenticated, hasSomePermissions } = useAuth()
    // 获取当前员工的单位下的所有staff的记录
    const { data: staffs, isLoading: staffsLoading } = isAuthenticated ?
        (hasSomePermissions(RolePerms.MANAGE_ANY_STAFF, RolePerms.MANAGE_DOM_STAFF) ?
            api.staff.findMany.useQuery() :
            api.staff.findByDept.useQuery({
                deptId: user.deptId
            })
        )
        : { data: null, isLoading: false }
    // 获取当前有体育成绩的员工的记录
    const {data:staffsWithScore,isLoading:staffsWithScoreLoading} = isAuthenticated ? 
        api.staff.findSportStaffByDept.useQuery({deptId:user.deptId})
        : { data: null, isLoading: false }
    return (
        <SportPageContext.Provider
            value={{
                sportProjectList: sportProjectList?.map((item) => ({
                    id: item.id,
                    name: item.name,
                    unit: item.unit,
                    trainContentId:item.trainContentId,
                    deletedAt:item.deletedAt,
                })) || [],
                newScoreForm,
                isNewScoreModalVisible,
                staffsWithScore,
                handlNewScoreOpen,
                handleNewScoreCancel,
                staffs: staffs as any as UserProfile[],
                staffsLoading,
                staffsWithScoreLoading
            }}>
            {children}
        </SportPageContext.Provider>
    );
}
export const useSportPageContext = () => {
    const context = useContext(SportPageContext);
    if (!context) {
        throw new Error("useSportPageContext must be used within SportPageProvider");
    }
    return context;
};
