import { getQueryKey } from "@trpc/react-query";
import { api } from "../trpc"; // Adjust path as necessary
import { useQueryClient } from "@tanstack/react-query";
import { ObjectType, Staff } from "@nice/common";
import { CrudOperation, emitDataChange } from "../../event";


export function useTrainSituation(){
    const queryClient = useQueryClient();
    const queryKey = getQueryKey(api.trainSituation);

    const create = api.trainSituation.create.useMutation({
        onSuccess: (res:any) => {
            queryClient.invalidateQueries({ queryKey });
            emitDataChange(ObjectType.TRAIN_SITUATION, res, CrudOperation.CREATED);
        },
    });

    const update = api.trainSituation.update.useMutation({
        onSuccess:(res:any)=>{
            queryClient.invalidateQueries({queryKey});
            emitDataChange(ObjectType.TRAIN_SITUATION,res,CrudOperation.UPDATED)
        }
    })

    const deleteSameGroupTrainSituation = api.trainSituation.deleteSameGroupTrainSituation.useMutation({
        onSuccess:(res:any) => {
            queryClient.invalidateQueries({queryKey})
            queryClient.invalidateQueries({queryKey:getQueryKey(api.trainContent)})
            queryClient.invalidateQueries({queryKey:getQueryKey(api.staff)})
            emitDataChange(ObjectType.TRAIN_SITUATION,res,CrudOperation.DELETED)
        }
    })

    const createManyTrainSituation = api.trainSituation.createManyTrainSituation.useMutation({
        onSuccess:(res:any) => {
            queryClient.invalidateQueries({queryKey})
            queryClient.invalidateQueries({queryKey:getQueryKey(api.trainContent)})
            queryClient.invalidateQueries({queryKey:getQueryKey(api.staff)})
            emitDataChange(ObjectType.TRAIN_SITUATION,res,CrudOperation.CREATED)
        }
    })
    
    return {
        create,
        update,
        deleteSameGroupTrainSituation,
        createManyTrainSituation
    }
}